// checkQueryParams.js
//
// example configuration:
//
// <Javascript name='JS-CheckQueryParams' timeLimit='200' >
//   <Properties>
//     <Property name='regex'>[-\'@\n,.*: ]</Property>
//   </Properties>
//   <ResourceURL>jsc://checkQueryParams.js</ResourceURL>
// </Javascript>
//

/* jshint strict: global */
/* global context: true, properties: true */

'use strict';

if ( ! properties.regex) {
  context.setVariable('queryparam_error', "missing regex");
}
else {
  try {
    var re1 = new RegExp(properties.regex);
    var qpnamesString = context.getVariable('message.queryparams.names') + '';
    var qpnames = qpnamesString.substr(1, qpnamesString.length - 2).split(', ');
    var firstError = false;
    //print ('qpnames: ' + JSON.stringify(qpnames));
    qpnames.forEach(function(name){
      if ( ! firstError) {
        var count = context.getVariable('message.queryparam.' + name + '.values.count');
        if (count == 1) {
          // there is just one instance of this named queryparam
          var v1 = context.getVariable('message.queryparam.' + name);
          //print ('qp(' + name + '): ' + v1);
          var m1 = v1.match(re1);
          if (m1) {
            firstError = name;
          }
        }
        else {
          // there are multiple query params of this name in the query string
          for (var i = 1; i <= count; i++) {
            var v2 = context.getVariable('message.queryparam.' + name + '.' + i);
            //print ('qp(' + name + ':' + i + '): ' + value);
            var m2 = v2.match(re1);
            if (m2) {
              firstError = name + ':' + i;
            }
          }
        }
      }
    });

    if (firstError) {
      context.setVariable('queryparam_error', firstError);
    }
  }
  catch(e) {
    context.setVariable('queryparam_error', "invalid regex");
  }

}
